Aludel
======

|aludel-ci|_

.. |aludel-ci| image:: https://travis-ci.org/praekelt/aludel.png?branch=develop
.. _aludel-ci: https://travis-ci.org/praekelt/aludel

|aludel-cover|_

.. |aludel-cover| image:: https://coveralls.io/repos/praekelt/aludel/badge.png?branch=develop
.. _aludel-cover: https://coveralls.io/r/praekelt/aludel


Aludel is a mini-framework for building RESTful APIs. It builds on top of
`alchimia`_ (for database things) and `klein`_ (for HTTP things).


How to use aludel
-----------------

TODO: Write some documentation for this.


About the name
--------------

An `aludel`_ is a subliming pot used in alchemy and medieval chemistry. It was
used as a condenser in the sublimation process and thus came to signify the
end-stages of transformation and the symbol of creation.

.. _alchimia: https://github.com/alex/alchimia
.. _klein: https://github.com/twisted/klein
.. _aludel: http://en.wikipedia.org/wiki/Aludel
